@@ -22,8 +22,8 @@ limitations under the License.
 package support
 
 import (
-	"bytes"
 	"bufio"
+	"bytes"
 	"context"
 	"encoding/json"
 	"errors"
@@ -36,9 +36,11 @@ import (
 	"testing"
 	"time"
 
+	"github.com/apache/camel-k/pkg/util/patch"
 	"github.com/google/uuid"
 	"github.com/onsi/gomega"
 	"github.com/spf13/cobra"
+	"k8s.io/apimachinery/pkg/types"
 
 	appsv1 "k8s.io/api/apps/v1"
 	"k8s.io/api/batch/v1beta1"
@@ -582,6 +584,79 @@ func ScaleIntegration(ns string, name string, replicas int32) error {
 	})
 }
 
+func KameletBinding(ns string, name string) func() *v1alpha1.KameletBinding {
+	return func() *v1alpha1.KameletBinding {
+		klb := v1alpha1.NewKameletBinding(ns, name)
+		key := ctrl.ObjectKey{
+			Namespace: ns,
+			Name:      name,
+		}
+		if err := TestClient().Get(TestContext, key, &klb); err != nil && !k8serrors.IsNotFound(err) {
+			panic(err)
+		} else if err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		}
+		return &klb
+	}
+}
+
+func KameletBindingSpecReplicas(ns string, name string) func() *int32 {
+	return func() *int32 {
+		klb := KameletBinding(ns, name)()
+		if klb == nil {
+			return nil
+		}
+		return klb.Spec.Replicas
+	}
+}
+
+func KameletBindingStatusReplicas(ns string, name string) func() *int32 {
+	return func() *int32 {
+		klb := KameletBinding(ns, name)()
+		if klb == nil {
+			return nil
+		}
+		return klb.Status.Replicas
+	}
+}
+
+func KameletBindingCondition(ns string, name string, conditionType v1alpha1.KameletBindingConditionType) func() corev1.ConditionStatus {
+	return func() corev1.ConditionStatus {
+		klb := KameletBinding(ns, name)()
+		if klb == nil {
+			return "KameletBindingMissing"
+		}
+		c := klb.Status.GetCondition(conditionType)
+		if c == nil {
+			return "ConditionMissing"
+		}
+		return c.Status
+	}
+}
+
+func UpdateKameletBinding(ns string, name string, upd func(it *v1alpha1.KameletBinding)) error {
+	klb := KameletBinding(ns, name)()
+	if klb == nil {
+		return fmt.Errorf("no kamelet binding named %s found", name)
+	}
+	target := klb.DeepCopy()
+	upd(target)
+	// For some reasons, full patch fails on some clusters
+	p, err := patch.PositiveMergePatch(klb, target)
+	if err != nil {
+		return err
+	} else if len(p) == 0 {
+		return nil
+	}
+	return TestClient().Patch(TestContext, target, ctrl.RawPatch(types.MergePatchType, p))
+}
+
+func ScaleKameletBinding(ns string, name string, replicas int32) error {
+	return UpdateKameletBinding(ns, name, func(klb *v1alpha1.KameletBinding) {
+		klb.Spec.Replicas = &replicas
+	})
+}
+
 func Kits(ns string, filters ...func(*v1.IntegrationKit) bool) func() []v1.IntegrationKit {
 	return func() []v1.IntegrationKit {
 		list := v1.NewIntegrationKitList()
@@ -956,6 +1031,33 @@ func ServiceAccount(ns, name string) func() *corev1.ServiceAccount {
 	}
 }
 
+func KameletList(ns string) func() []v1alpha1.Kamelet {
+	return func() []v1alpha1.Kamelet {
+		lst := v1alpha1.NewKameletList()
+		err := TestClient().List(TestContext, &lst, ctrl.InNamespace(ns))
+		if err != nil {
+			panic(err)
+		}
+		return lst.Items
+	}
+}
+
+func Kamelet(name string, ns string) func() *v1alpha1.Kamelet {
+	return func() *v1alpha1.Kamelet {
+		it := v1alpha1.NewKamelet(ns, name)
+		key := ctrl.ObjectKey{
+			Namespace: ns,
+			Name:      name,
+		}
+		if err := TestClient().Get(TestContext, key, &it); err != nil && !k8serrors.IsNotFound(err) {
+			panic(err)
+		} else if err != nil && k8serrors.IsNotFound(err) {
+			return nil
+		}
+		return &it
+	}
+}
+
 /*
 	Tekton
 */
@@ -969,7 +1071,13 @@ func CreateOperatorRole(ns string) (err error) {
 	if err != nil {
 		panic(err)
 	}
-	err = install.Resource(TestContext, TestClient(), ns, true, install.IdentityResourceCustomizer, "/rbac/operator-role-kubernetes.yaml")
+	customizer := install.IdentityResourceCustomizer
+	if oc {
+		// Remove Ingress permissions as it's not needed on OpenShift
+		// This should ideally be removed from the common RBAC manifest.
+		customizer = install.RemoveIngressRoleCustomizer
+	}
+	err = install.Resource(TestContext, TestClient(), ns, true, customizer, "/rbac/operator-role-kubernetes.yaml")
 	if err != nil {
 		return err
 	}
@@ -1345,3 +1453,15 @@ func GetOutputString(command *cobra.Command) string {
 
 	return buf.String()
 }
+
+func GetOutputStringAsync(cmd *cobra.Command) func() string {
+	var buffer bytes.Buffer
+	stdout := bufio.NewWriter(&buffer)
+
+	cmd.SetOut(stdout)
+	go cmd.Execute()
+
+	return func() string {
+		return buffer.String()
+	}
+}
