@@ -22,10 +22,15 @@ import (
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 )
 
+const TraitAnnotationPrefix = "trait.camel.apache.org/"
+
 // ConfigurationSpec --
 type ConfigurationSpec struct {
-	Type  string `json:"type"`
-	Value string `json:"value"`
+	Type               string `json:"type"`
+	Value              string `json:"value"`
+	ResourceType       string `json:"resourceType,omitempty"`
+	ResourceMountPoint string `json:"resourceMountPoint,omitempty"`
+	ResourceKey        string `json:"resourceKey,omitempty"`
 }
 
 // Artifact --
@@ -61,21 +66,24 @@ type TraitConfiguration struct {
 	RawMessage `json:",inline"`
 }
 
-// RawMessage is a raw encoded JSON value.
-// It implements Marshaler and Unmarshaler and can
-// be used to delay JSON decoding or precompute a JSON encoding.
 // +kubebuilder:validation:Type=object
 // +kubebuilder:validation:Format=""
 // +kubebuilder:pruning:PreserveUnknownFields
+
+// RawMessage is a raw encoded JSON value.
+// It implements Marshaler and Unmarshaler and can
+// be used to delay JSON decoding or precompute a JSON encoding.
 type RawMessage []byte
 
 // +kubebuilder:object:generate=false
+
 // Configurable --
 type Configurable interface {
 	Configurations() []ConfigurationSpec
 }
 
 // +kubebuilder:object:generate=false
+
 // PlatformInjectable --
 type PlatformInjectable interface {
 	SetIntegrationPlatform(platform *IntegrationPlatform)
@@ -83,8 +91,13 @@ type PlatformInjectable interface {
 
 // MavenSpec --
 type MavenSpec struct {
-	LocalRepository string      `json:"localRepository,omitempty"`
-	Settings        ValueSource `json:"settings,omitempty"`
+	// The path of the local Maven repository.
+	LocalRepository string `json:"localRepository,omitempty"`
+	// The Maven properties.
+	Properties map[string]string `json:"properties,omitempty"`
+	// A reference to the ConfigMap or Secret key that contains
+	// the Maven settings.
+	Settings ValueSource `json:"settings,omitempty"`
 	// The Secret name and key, containing the CA certificate(s) used to connect
 	// to remote Maven repositories.
 	// It can contain X.509 certificates, and PKCS#7 formatted certificate chains.
@@ -92,7 +105,11 @@ type MavenSpec struct {
 	// and configured to be used as a trusted certificate(s) by the Maven commands.
 	// Note that the root CA certificates are also imported into the created keystore.
 	CASecret *corev1.SecretKeySelector `json:"caSecret,omitempty"`
-	Timeout  *metav1.Duration          `json:"timeout,omitempty"`
+	// Deprecated: use IntegrationPlatform.Spec.Build.Timeout instead
+	Timeout      *metav1.Duration `json:"timeout,omitempty"`
+	Repositories []Repository     `json:"repositories,omitempty"`
+	// Maven build extensions https://maven.apache.org/guides/mini/guide-using-extensions.html
+	Extension []MavenArtifact `json:"extension,omitempty"`
 }
 
 // ValueSource --
@@ -105,9 +122,9 @@ type ValueSource struct {
 
 // MavenArtifact --
 type MavenArtifact struct {
-	GroupID    string `json:"groupId" yaml:"groupId"`
-	ArtifactID string `json:"artifactId" yaml:"artifactId"`
-	Version    string `json:"version,omitempty" yaml:"version,omitempty"`
+	GroupID    string `json:"groupId" yaml:"groupId" xml:"groupId"`
+	ArtifactID string `json:"artifactId" yaml:"artifactId" xml:"artifactId"`
+	Version    string `json:"version,omitempty" yaml:"version,omitempty" xml:"version,omitempty"`
 }
 
 // RuntimeSpec --
@@ -138,7 +155,7 @@ const (
 	CapabilityCron = "cron"
 	// CapabilityPlatformHTTP --
 	CapabilityPlatformHTTP = "platform-http"
-	// CapabilityCircuitBreaker
+	// CapabilityCircuitBreaker --
 	CapabilityCircuitBreaker = "circuit-breaker"
 	// CapabilityTracing --
 	CapabilityTracing = "tracing"
@@ -147,6 +164,7 @@ const (
 )
 
 // +kubebuilder:object:generate=false
+
 // ResourceCondition is a common type for all conditions
 type ResourceCondition interface {
 	GetType() string
@@ -162,6 +180,11 @@ type Flow struct {
 	RawMessage `json:",inline"`
 }
 
+// Template is an unstructured object representing a Kamelet template in YAML/JSON DSL
+type Template struct {
+	RawMessage `json:",inline"`
+}
+
 // RuntimeProvider --
 type RuntimeProvider string
 
@@ -181,9 +204,11 @@ type ResourceSpec struct {
 }
 
 const (
-	// ResourceTypeData --
+	// ResourceTypeData represents a generic data resource
 	ResourceTypeData ResourceType = "data"
-	// ResourceTypeOpenAPI --
+	// ResourceTypeConfig represents a config resource known to runtime
+	ResourceTypeConfig ResourceType = "config"
+	// ResourceTypeOpenAPI represents an OpenAPI config resource
 	ResourceTypeOpenAPI ResourceType = "openapi"
 )
 
@@ -214,6 +239,7 @@ const (
 // DataSpec --
 type DataSpec struct {
 	Name        string `json:"name,omitempty"`
+	Path        string `json:"path,omitempty"`
 	Content     string `json:"content,omitempty"`
 	RawContent  []byte `json:"rawContent,omitempty"`
 	ContentRef  string `json:"contentRef,omitempty"`
