@@ -27,48 +27,57 @@ import (
 
 // IntegrationSpec defines the desired state of Integration
 type IntegrationSpec struct {
-	Replicas           *int32               `json:"replicas,omitempty"`
-	Sources            []SourceSpec         `json:"sources,omitempty"`
-	Flows              []Flow               `json:"flows,omitempty"`
-	Resources          []ResourceSpec       `json:"resources,omitempty"`
-	Kit                string               `json:"kit,omitempty"`
-	Dependencies       []string             `json:"dependencies,omitempty"`
-	Profile            TraitProfile         `json:"profile,omitempty"`
-	Traits             map[string]TraitSpec `json:"traits,omitempty"`
-	Configuration      []ConfigurationSpec  `json:"configuration,omitempty"`
-	Repositories       []string             `json:"repositories,omitempty"`
-	ServiceAccountName string               `json:"serviceAccountName,omitempty"`
+	Replicas  *int32         `json:"replicas,omitempty"`
+	Sources   []SourceSpec   `json:"sources,omitempty"`
+	Flows     []Flow         `json:"flows,omitempty"`
+	Resources []ResourceSpec `json:"resources,omitempty"`
+	// Deprecated: use the IntegrationKit field
+	Kit                string                  `json:"kit,omitempty"`
+	IntegrationKit     *corev1.ObjectReference `json:"integrationKit,omitempty"`
+	Dependencies       []string                `json:"dependencies,omitempty"`
+	Profile            TraitProfile            `json:"profile,omitempty"`
+	Traits             map[string]TraitSpec    `json:"traits,omitempty"`
+	PodTemplate        *PodSpecTemplate        `json:"template,omitempty"`
+	Configuration      []ConfigurationSpec     `json:"configuration,omitempty"`
+	Repositories       []string                `json:"repositories,omitempty"`
+	ServiceAccountName string                  `json:"serviceAccountName,omitempty"`
 }
 
 // IntegrationStatus defines the observed state of Integration
 type IntegrationStatus struct {
-	Phase              IntegrationPhase       `json:"phase,omitempty"`
-	Digest             string                 `json:"digest,omitempty"`
-	Image              string                 `json:"image,omitempty"`
-	Dependencies       []string               `json:"dependencies,omitempty"`
-	Profile            TraitProfile           `json:"profile,omitempty"`
-	Kit                string                 `json:"kit,omitempty"`
-	Platform           string                 `json:"platform,omitempty"`
-	GeneratedSources   []SourceSpec           `json:"generatedSources,omitempty"`
-	GeneratedResources []ResourceSpec         `json:"generatedResources,omitempty"`
-	Failure            *Failure               `json:"failure,omitempty"`
-	RuntimeVersion     string                 `json:"runtimeVersion,omitempty"`
-	RuntimeProvider    RuntimeProvider        `json:"runtimeProvider,omitempty"`
-	Configuration      []ConfigurationSpec    `json:"configuration,omitempty"`
-	Conditions         []IntegrationCondition `json:"conditions,omitempty"`
-	Version            string                 `json:"version,omitempty"`
-	Replicas           *int32                 `json:"replicas,omitempty"`
-	Selector           string                 `json:"selector,omitempty"`
-	Capabilities       []string               `json:"capabilities,omitempty"`
+	Phase        IntegrationPhase `json:"phase,omitempty"`
+	Digest       string           `json:"digest,omitempty"`
+	Image        string           `json:"image,omitempty"`
+	Dependencies []string         `json:"dependencies,omitempty"`
+	Profile      TraitProfile     `json:"profile,omitempty"`
+	// Deprecated: use the IntegrationKit field
+	Kit                string                  `json:"kit,omitempty"`
+	IntegrationKit     *corev1.ObjectReference `json:"integrationKit,omitempty"`
+	Platform           string                  `json:"platform,omitempty"`
+	GeneratedSources   []SourceSpec            `json:"generatedSources,omitempty"`
+	GeneratedResources []ResourceSpec          `json:"generatedResources,omitempty"`
+	RuntimeVersion     string                  `json:"runtimeVersion,omitempty"`
+	RuntimeProvider    RuntimeProvider         `json:"runtimeProvider,omitempty"`
+	Configuration      []ConfigurationSpec     `json:"configuration,omitempty"`
+	Conditions         []IntegrationCondition  `json:"conditions,omitempty"`
+	Version            string                  `json:"version,omitempty"`
+	Replicas           *int32                  `json:"replicas,omitempty"`
+	Selector           string                  `json:"selector,omitempty"`
+	Capabilities       []string                `json:"capabilities,omitempty"`
+	// The timestamp representing the last time when this integration was initialized.
+	InitializationTimestamp *metav1.Time `json:"lastInitTimestamp,omitempty"`
 }
 
 // +genclient
+// +genclient:method=GetScale,verb=get,subresource=scale,result=k8s.io/api/autoscaling/v1.Scale
+// +genclient:method=UpdateScale,verb=update,subresource=scale,input=k8s.io/api/autoscaling/v1.Scale,result=k8s.io/api/autoscaling/v1.Scale
 // +kubebuilder:object:root=true
 // +kubebuilder:resource:path=integrations,scope=Namespaced,shortName=it,categories=kamel;camel
 // +kubebuilder:subresource:status
+// +kubebuilder:storageversion
 // +kubebuilder:subresource:scale:specpath=.spec.replicas,statuspath=.status.replicas,selectorpath=.status.selector
 // +kubebuilder:printcolumn:name="Phase",type=string,JSONPath=`.status.phase`,description="The integration phase"
-// +kubebuilder:printcolumn:name="Kit",type=string,JSONPath=`.status.kit`,description="The integration kit"
+// +kubebuilder:printcolumn:name="Kit",type=string,JSONPath=`.status.integrationKit.name`,description="The integration kit"
 // +kubebuilder:printcolumn:name="Replicas",type=integer,JSONPath=`.status.replicas`,description="The number of pods"
 
 // Integration is the Schema for the integrations API
@@ -89,83 +98,6 @@ type IntegrationList struct {
 	Items           []Integration `json:"items"`
 }
 
-// DataSpec --
-type DataSpec struct {
-	Name        string `json:"name,omitempty"`
-	Content     string `json:"content,omitempty"`
-	ContentRef  string `json:"contentRef,omitempty"`
-	ContentKey  string `json:"contentKey,omitempty"`
-	Compression bool   `json:"compression,omitempty"`
-}
-
-// ResourceType --
-type ResourceType string
-
-// ResourceSpec --
-type ResourceSpec struct {
-	DataSpec  `json:",inline"`
-	Type      ResourceType `json:"type,omitempty"`
-	MountPath string       `json:"mountPath,omitempty"`
-}
-
-const (
-	// ResourceTypeData --
-	ResourceTypeData ResourceType = "data"
-	// ResourceTypeOpenAPI --
-	ResourceTypeOpenAPI ResourceType = "openapi"
-)
-
-// SourceSpec --
-type SourceSpec struct {
-	DataSpec `json:",inline"`
-	Language Language `json:"language,omitempty"`
-	// Loader is an optional id of the org.apache.camel.k.RoutesLoader that will
-	// interpret this source at runtime
-	Loader string `json:"loader,omitempty"`
-	// Interceptors are optional identifiers the org.apache.camel.k.RoutesLoader
-	// uses to pre/post process sources
-	Interceptors []string `json:"interceptors,omitempty"`
-	// Type defines the kind of source described by this object
-	Type SourceType `json:"type,omitempty"`
-	// List of property names defined in the source (e.g. if type is "template")
-	PropertyNames []string `json:"property-names,omitempty"`
-}
-
-type SourceType string
-
-const (
-	SourceTypeDefault  SourceType = ""
-	SourceTypeTemplate SourceType = "template"
-)
-
-// Language --
-type Language string
-
-const (
-	// LanguageJavaSource --
-	LanguageJavaSource Language = "java"
-	// LanguageGroovy --
-	LanguageGroovy Language = "groovy"
-	// LanguageJavaScript --
-	LanguageJavaScript Language = "js"
-	// LanguageXML --
-	LanguageXML Language = "xml"
-	// LanguageKotlin --
-	LanguageKotlin Language = "kts"
-	// LanguageYaml --
-	LanguageYaml Language = "yaml"
-)
-
-// Languages is the list of all supported languages
-var Languages = []Language{
-	LanguageJavaSource,
-	LanguageGroovy,
-	LanguageJavaScript,
-	LanguageXML,
-	LanguageKotlin,
-	LanguageYaml,
-}
-
 // IntegrationPhase --
 type IntegrationPhase string
 
@@ -186,12 +118,12 @@ const (
 	IntegrationPhaseBuildingKit IntegrationPhase = "Building Kit"
 	// IntegrationPhaseResolvingKit --
 	IntegrationPhaseResolvingKit IntegrationPhase = "Resolving Kit"
+	// IntegrationPhaseWaitingForBindings e.g Service Bindings --
+	IntegrationPhaseWaitingForBindings IntegrationPhase = "Waiting for Bindings"
 	// IntegrationPhaseDeploying --
 	IntegrationPhaseDeploying IntegrationPhase = "Deploying"
 	// IntegrationPhaseRunning --
 	IntegrationPhaseRunning IntegrationPhase = "Running"
-	// IntegrationPhaseUpdating is a phase where the operator is not supposed to interact with the resource
-	IntegrationPhaseUpdating IntegrationPhase = "Updating"
 	// IntegrationPhaseError --
 	IntegrationPhaseError IntegrationPhase = "Error"
 
@@ -207,6 +139,8 @@ const (
 	IntegrationConditionKnativeServiceAvailable IntegrationConditionType = "KnativeServiceAvailable"
 	// IntegrationConditionCronJobAvailable --
 	IntegrationConditionCronJobAvailable IntegrationConditionType = "CronJobAvailable"
+	// IntegrationConditionServiceBindingsCollectionReady --
+	IntegrationConditionServiceBindingsCollectionReady IntegrationConditionType = "ServiceBindingsCollectionReady"
 	// IntegrationConditionExposureAvailable --
 	IntegrationConditionExposureAvailable IntegrationConditionType = "ExposureAvailable"
 	// IntegrationConditionPrometheusAvailable --
@@ -262,6 +196,13 @@ const (
 	IntegrationConditionReplicaSetReadyReason string = "ReplicaSetReady"
 	// IntegrationConditionReplicaSetNotReadyReason --
 	IntegrationConditionReplicaSetNotReadyReason string = "ReplicaSetNotReady"
+
+	// IntegrationConditionKameletsAvailable --
+	IntegrationConditionKameletsAvailable IntegrationConditionType = "KameletsAvailable"
+	// IntegrationConditionKameletsAvailableReason --
+	IntegrationConditionKameletsAvailableReason string = "KameletsAvailable"
+	// IntegrationConditionKameletsNotAvailableReason --
+	IntegrationConditionKameletsNotAvailableReason string = "KameletsNotAvailable"
 )
 
 // IntegrationCondition describes the state of a resource at a certain point.
@@ -274,8 +215,35 @@ type IntegrationCondition struct {
 	LastUpdateTime metav1.Time `json:"lastUpdateTime,omitempty"`
 	// Last time the condition transitioned from one status to another.
 	LastTransitionTime metav1.Time `json:"lastTransitionTime,omitempty"`
+	// First time the condition status transitioned to True.
+	FirstTruthyTime *metav1.Time `json:"firstTruthyTime,omitempty"`
 	// The reason for the condition's last transition.
 	Reason string `json:"reason,omitempty"`
 	// A human readable message indicating details about the transition.
 	Message string `json:"message,omitempty"`
 }
+type PodSpecTemplate struct {
+	Spec PodSpec `json:"spec,omitempty"`
+}
+
+type PodSpec struct {
+	Volumes []corev1.Volume `json:"volumes,omitempty" patchStrategy:"merge,retainKeys" patchMergeKey:"name" protobuf:"bytes,1,rep,name=volumes"`
+
+	InitContainers []corev1.Container `json:"initContainers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,20,rep,name=initContainers"`
+
+	Containers []corev1.Container `json:"containers" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,2,rep,name=containers"`
+
+	EphemeralContainers []corev1.EphemeralContainer `json:"ephemeralContainers,omitempty" patchStrategy:"merge" patchMergeKey:"name" protobuf:"bytes,34,rep,name=ephemeralContainers"`
+
+	RestartPolicy corev1.RestartPolicy `json:"restartPolicy,omitempty" protobuf:"bytes,3,opt,name=restartPolicy,casttype=RestartPolicy"`
+
+	TerminationGracePeriodSeconds *int64 `json:"terminationGracePeriodSeconds,omitempty" protobuf:"varint,4,opt,name=terminationGracePeriodSeconds"`
+
+	ActiveDeadlineSeconds *int64 `json:"activeDeadlineSeconds,omitempty" protobuf:"varint,5,opt,name=activeDeadlineSeconds"`
+
+	DNSPolicy corev1.DNSPolicy `json:"dnsPolicy,omitempty" protobuf:"bytes,6,opt,name=dnsPolicy,casttype=DNSPolicy"`
+
+	NodeSelector map[string]string `json:"nodeSelector,omitempty" protobuf:"bytes,7,rep,name=nodeSelector"`
+
+	TopologySpreadConstraints []corev1.TopologySpreadConstraint `json:"topologySpreadConstraints,omitempty" patchStrategy:"merge" patchMergeKey:"topologyKey" protobuf:"bytes,33,opt,name=topologySpreadConstraints"`
+}
