@@ -132,14 +132,14 @@ func createKamelWithModelineCommand(ctx context.Context, args []string) (*cobra.
 		return nil, nil, errors.Wrap(err, "cannot read sources")
 	}
 
-	// Extract list of property names already specified by the user.
-	userPropertyNames := []string{}
+	// Extract list of property/trait names already specified by the user.
+	cliParamNames := []string{}
 	index := 0
 	for _, arg := range args {
-		if arg == "-p" || arg == "--property" {
-			// Property is assumed to be in the form: <name>=<value>
+		if arg == "-p" || arg == "--property" || arg == "-t" || arg == "--trait" || arg == "--build-property" {
+			// Property or trait is assumed to be in the form: <name>=<value>
 			splitValues := strings.Split(args[index+1], "=")
-			userPropertyNames = append(userPropertyNames, splitValues[0])
+			cliParamNames = append(cliParamNames, splitValues[0])
 		}
 		index++
 	}
@@ -148,19 +148,19 @@ func createKamelWithModelineCommand(ctx context.Context, args []string) (*cobra.
 	nOpts := 0
 	for _, o := range opts {
 		// Check if property name is given by user.
-		propertyAlreadySpecifiedByUser := false
-		if o.Name == "property" {
-			propertyComponents := strings.Split(o.Value, "=")
-			for _, propName := range userPropertyNames {
-				if propName == propertyComponents[0] {
-					propertyAlreadySpecifiedByUser = true
+		paramAlreadySpecifiedByUser := false
+		if o.Name == "property" || o.Name == "trait" || o.Name == "build-property" {
+			paramComponents := strings.Split(o.Value, "=")
+			for _, paramName := range cliParamNames {
+				if paramName == paramComponents[0] {
+					paramAlreadySpecifiedByUser = true
 					break
 				}
 			}
 		}
 
 		// Skip properties already specified by the user otherwise add all options.
-		if !propertyAlreadySpecifiedByUser && !nonRunOptions[o.Name] {
+		if !paramAlreadySpecifiedByUser && !nonRunOptions[o.Name] {
 			opts[nOpts] = o
 			nOpts++
 		}
