@@ -76,30 +76,13 @@ func ConfigureDefaults(ctx context.Context, c client.Client, p *v1.IntegrationPl
 	}
 
 	if p.Status.Build.BuildStrategy == "" {
-		operatorIsLocal := !IsCurrentOperatorGlobal()
-		// Local operators build in the same namespace by definition
-		buildInDifferentNamespace := !operatorIsLocal
-		if !operatorIsLocal {
-			// Unless it's a global operator using a globally shared integration platform
-			buildInDifferentNamespace = p.Namespace != GetOperatorNamespace()
-		}
-
-		// If the operator and the build are in different namespaces, pod strategy should be used (except for Spectrum)
-		if buildInDifferentNamespace {
-			if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategySpectrum {
-				p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyRoutine
-			} else {
-				p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyPod
-			}
+		// Use the fastest strategy that they support (routine when possible)
+		if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyS2I ||
+			p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategySpectrum {
+			p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyRoutine
 		} else {
-			// Same-namespace builds use the fastest strategy that they support (routine when possible)
-			if p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategyS2I ||
-				p.Status.Build.PublishStrategy == v1.IntegrationPlatformBuildPublishStrategySpectrum {
-				p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyRoutine
-			} else {
-				// The build output has to be shared via a volume
-				p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyPod
-			}
+			// The build output has to be shared via a volume
+			p.Status.Build.BuildStrategy = v1.IntegrationPlatformBuildStrategyPod
 		}
 	}
 
@@ -123,8 +106,8 @@ func ConfigureDefaults(ctx context.Context, c client.Client, p *v1.IntegrationPl
 		log.Log.Info("No registry specified for publishing images")
 	}
 
-	if verbose && p.Status.Build.Maven.GetTimeout().Duration != 0 {
-		log.Log.Infof("Maven Timeout set to %s", p.Status.Build.Maven.GetTimeout().Duration)
+	if verbose && p.Status.Build.GetTimeout().Duration != 0 {
+		log.Log.Infof("Maven Timeout set to %s", p.Status.Build.GetTimeout().Duration)
 	}
 
 	return nil
@@ -201,26 +184,8 @@ func setPlatformDefaults(ctx context.Context, c client.Client, p *v1.Integration
 		}
 	}
 
-	if p.Status.Build.Maven.GetTimeout().Duration != 0 {
-		d := p.Status.Build.Maven.GetTimeout().Duration.Truncate(time.Second)
-
-		if verbose && p.Status.Build.Maven.GetTimeout().Duration != d {
-			log.Log.Infof("Maven timeout minimum unit is sec (configured: %s, truncated: %s)", p.Status.Build.Maven.GetTimeout().Duration, d)
-		}
-
-		p.Status.Build.Maven.Timeout = &metav1.Duration{
-			Duration: d,
-		}
-	}
-	if p.Status.Build.Maven.GetTimeout().Duration == 0 {
-		n := p.Status.Build.GetTimeout().Duration.Seconds() * 0.75
-		p.Status.Build.Maven.Timeout = &metav1.Duration{
-			Duration: (time.Duration(n) * time.Second).Truncate(time.Second),
-		}
-	}
-
 	if p.Status.Build.Maven.Settings.ConfigMapKeyRef == nil && p.Status.Build.Maven.Settings.SecretKeyRef == nil {
-		var repositories []maven.Repository
+		var repositories []v1.Repository
 		var mirrors []maven.Mirror
 		for i, c := range p.Status.Configuration {
 			if c.Type == "repository" {
@@ -231,11 +196,11 @@ func setPlatformDefaults(ctx context.Context, c client.Client, p *v1.Integration
 					}
 					mirrors = append(mirrors, mirror)
 				} else {
-					repository := maven.NewRepository(c.Value)
-					if repository.ID == "" {
-						repository.ID = fmt.Sprintf("repository-%03d", i)
+					repo := maven.NewRepository(c.Value)
+					if repo.ID == "" {
+						repo.ID = fmt.Sprintf("repository-%03d", i)
 					}
-					repositories = append(repositories, repository)
+					repositories = append(repositories, repo)
 				}
 			}
 		}
@@ -277,7 +242,6 @@ func setPlatformDefaults(ctx context.Context, c client.Client, p *v1.Integration
 		log.Log.Infof("BaseImage set to %s", p.Status.Build.BaseImage)
 		log.Log.Infof("LocalRepository set to %s", p.Status.Build.Maven.LocalRepository)
 		log.Log.Infof("Timeout set to %s", p.Status.Build.GetTimeout())
-		log.Log.Infof("Maven Timeout set to %s", p.Status.Build.Maven.GetTimeout().Duration)
 	}
 
 	return nil
