@@ -74,14 +74,16 @@ type containerTrait struct {
 	ServicePort int `property:"service-port" json:"servicePort,omitempty"`
 	// To configure under which service port name the container port is to be exposed (default `http`).
 	ServicePortName string `property:"service-port-name" json:"servicePortName,omitempty"`
-
 	// The main container name. It's named `integration` by default.
 	Name string `property:"name" json:"name,omitempty"`
 	// The main container image
 	Image string `property:"image" json:"image,omitempty"`
-
+	// The pull policy: Always|Never|IfNotPresent
+	ImagePullPolicy corev1.PullPolicy `property:"image-pull-policy" json:"imagePullPolicy,omitempty"`
 	// ProbesEnabled enable/disable probes on the container (default `false`)
 	ProbesEnabled *bool `property:"probes-enabled" json:"probesEnabled,omitempty"`
+	// Scheme to use when connecting. Defaults to HTTP. Applies to the liveness probe.
+	LivenessScheme string `property:"liveness-scheme" json:"livenessScheme,omitempty"`
 	// Number of seconds after the container has started before liveness probes are initiated.
 	LivenessInitialDelay int32 `property:"liveness-initial-delay" json:"livenessInitialDelay,omitempty"`
 	// Number of seconds after which the probe times out. Applies to the liveness probe.
@@ -94,6 +96,8 @@ type containerTrait struct {
 	// Minimum consecutive failures for the probe to be considered failed after having succeeded.
 	// Applies to the liveness probe.
 	LivenessFailureThreshold int32 `property:"liveness-failure-threshold" json:"livenessFailureThreshold,omitempty"`
+	// Scheme to use when connecting. Defaults to HTTP. Applies to the readiness probe.
+	ReadinessScheme string `property:"readiness-scheme" json:"readinessScheme,omitempty"`
 	// Number of seconds after the container has started before readiness probes are initiated.
 	ReadinessInitialDelay int32 `property:"readiness-initial-delay" json:"readinessInitialDelay,omitempty"`
 	// Number of seconds after which the probe times out. Applies to the readiness probe.
@@ -115,12 +119,14 @@ func newContainerTrait() Trait {
 		ServicePort:     defaultServicePort,
 		ServicePortName: defaultContainerPortName,
 		Name:            defaultContainerName,
-		ProbesEnabled:   util.BoolP(false),
+		ProbesEnabled:   BoolP(false),
+		LivenessScheme:  string(corev1.URISchemeHTTP),
+		ReadinessScheme: string(corev1.URISchemeHTTP),
 	}
 }
 
 func (t *containerTrait) Configure(e *Environment) (bool, error) {
-	if t.Enabled != nil && !*t.Enabled {
+	if IsFalse(t.Enabled) {
 		return false, nil
 	}
 
@@ -128,16 +134,24 @@ func (t *containerTrait) Configure(e *Environment) (bool, error) {
 		return false, nil
 	}
 
-	if util.IsNilOrTrue(t.Auto) {
+	if IsNilOrTrue(t.Auto) {
 		if t.Expose == nil {
 			e := e.Resources.GetServiceForIntegration(e.Integration) != nil
 			t.Expose = &e
 		}
 	}
 
+	if !isValidPullPolicy(t.ImagePullPolicy) {
+		return false, fmt.Errorf("unsupported pull policy %s", t.ImagePullPolicy)
+	}
+
 	return true, nil
 }
 
+func isValidPullPolicy(policy corev1.PullPolicy) bool {
+	return policy == "" || policy == corev1.PullAlways || policy == corev1.PullIfNotPresent || policy == corev1.PullNever
+}
+
 func (t *containerTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
 		return t.configureDependencies(e)
@@ -187,7 +201,7 @@ func (t *containerTrait) configureDependencies(e *Environment) error {
 			e.Resources.Add(&kit)
 			e.Integration.SetIntegrationKit(&kit)
 		}
-		if util.IsTrue(t.ProbesEnabled) {
+		if IsTrue(t.ProbesEnabled) {
 			if capability, ok := e.CamelCatalog.Runtime.Capabilities[v1.CapabilityHealth]; ok {
 				for _, dependency := range capability.Dependencies {
 					util.StringSliceUniqueAdd(&e.Integration.Status.Dependencies, dependency.GetDependencyID())
@@ -214,6 +228,10 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 		Env:   make([]corev1.EnvVar, 0),
 	}
 
+	if t.ImagePullPolicy != "" {
+		container.ImagePullPolicy = t.ImagePullPolicy
+	}
+
 	// combine Environment of integration with platform, kit, integration
 	for _, env := range e.collectConfigurationPairs("env") {
 		envvar.SetVal(&container.Env, env.Name, env.Value)
@@ -227,7 +245,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 
 	t.configureResources(e, &container)
 
-	if t.Expose != nil && *t.Expose {
+	if IsTrue(t.Expose) {
 		t.configureService(e, &container)
 	}
 	t.configureCapabilities(e)
@@ -238,7 +256,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 	}
 	// Deployment
 	if err := e.Resources.VisitDeploymentE(func(deployment *appsv1.Deployment) error {
-		if util.IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
+		if IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
 			t.configureProbes(&container, t.Port, defaultProbePath)
 		}
 
@@ -265,7 +283,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 
 	// Knative Service
 	if err := e.Resources.VisitKnativeServiceE(func(service *serving.Service) error {
-		if util.IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
+		if IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
 			// don't set the port on Knative service as it is not allowed.
 			t.configureProbes(&container, 0, defaultProbePath)
 		}
@@ -304,7 +322,7 @@ func (t *containerTrait) configureContainer(e *Environment) error {
 
 	// CronJob
 	if err := e.Resources.VisitCronJobE(func(cron *v1beta1.CronJob) error {
-		if util.IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
+		if IsTrue(t.ProbesEnabled) && portName == defaultContainerPortName {
 			t.configureProbes(&container, t.Port, defaultProbePath)
 		}
 
@@ -434,6 +452,7 @@ func (t *containerTrait) configureProbes(container *corev1.Container, port int,
 func (t *containerTrait) newLivenessProbe(port int, path string) *corev1.Probe {
 	action := corev1.HTTPGetAction{}
 	action.Path = path
+	action.Scheme = corev1.URIScheme(t.LivenessScheme)
 
 	if port > 0 {
 		action.Port = intstr.FromInt(port)
@@ -458,8 +477,9 @@ func (t *containerTrait) newReadinessProbe(port int, path string) *corev1.Probe
 	p := corev1.Probe{
 		Handler: corev1.Handler{
 			HTTPGet: &corev1.HTTPGetAction{
-				Port: intstr.FromInt(port),
-				Path: path,
+				Port:   intstr.FromInt(port),
+				Path:   path,
+				Scheme: corev1.URIScheme(t.ReadinessScheme),
 			},
 		},
 	}
