@@ -18,6 +18,9 @@ limitations under the License.
 package trait
 
 import (
+	"fmt"
+	"strings"
+
 	v1 "github.com/apache/camel-k/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/pkg/apis/camel/v1alpha1"
 	"gopkg.in/yaml.v2"
@@ -34,7 +37,8 @@ type errorHandlerTrait struct {
 
 func newErrorHandlerTrait() Trait {
 	return &errorHandlerTrait{
-		BaseTrait: NewBaseTrait("error-handler", 500),
+		// NOTE: Must run before dependency trait
+		BaseTrait: NewBaseTrait("error-handler", 470),
 	}
 }
 
@@ -44,7 +48,7 @@ func (t *errorHandlerTrait) IsPlatformTrait() bool {
 }
 
 func (t *errorHandlerTrait) Configure(e *Environment) (bool, error) {
-	if t.Enabled != nil && !*t.Enabled {
+	if IsFalse(t.Enabled) {
 		return false, nil
 	}
 
@@ -61,11 +65,31 @@ func (t *errorHandlerTrait) Configure(e *Environment) (bool, error) {
 
 func (t *errorHandlerTrait) Apply(e *Environment) error {
 	if e.IntegrationInPhase(v1.IntegrationPhaseInitialization) {
+		// If the user configure directly the URI, we need to autodiscover the underlying component
+		// and add the related dependency
+		defaultErrorHandlerURI := e.Integration.Spec.GetConfigurationProperty(
+			fmt.Sprintf("%s.deadLetterUri", v1alpha1.ErrorHandlerAppPropertiesPrefix))
+		if defaultErrorHandlerURI != "" && !strings.HasPrefix(defaultErrorHandlerURI, "kamelet:") {
+			t.addErrorHandlerDependencies(e, defaultErrorHandlerURI)
+		}
+
 		return t.addErrorHandlerAsSource(e)
 	}
 	return nil
 }
 
+func (t *errorHandlerTrait) addErrorHandlerDependencies(e *Environment, uri string) {
+	candidateComp, scheme := e.CamelCatalog.DecodeComponent(uri)
+	if candidateComp != nil {
+		e.Integration.Spec.AddDependency(candidateComp.GetDependencyID())
+		if scheme != nil {
+			for _, dep := range candidateComp.GetProducerDependencyIDs(scheme.ID) {
+				e.Integration.Spec.AddDependency(dep)
+			}
+		}
+	}
+}
+
 func (t *errorHandlerTrait) addErrorHandlerAsSource(e *Environment) error {
 	flowErrorHandler := map[string]interface{}{
 		"error-handler": map[string]string{
