@@ -52,6 +52,17 @@ func TestBindings(t *testing.T) {
 			},
 			uri: "knative:endpoint/myservice?apiVersion=serving.knative.dev%2Fv1&kind=Service",
 		},
+		{
+			endpointType: v1alpha1.EndpointTypeAction,
+			endpoint: v1alpha1.Endpoint{
+				Ref: &corev1.ObjectReference{
+					Kind:       "Service",
+					APIVersion: "serving.knative.dev/v1",
+					Name:       "myservice",
+				},
+			},
+			uri: "knative:endpoint/myservice?apiVersion=serving.knative.dev%2Fv1&kind=Service",
+		},
 		{
 			endpointType: v1alpha1.EndpointTypeSink,
 			endpoint: v1alpha1.Endpoint{
@@ -104,14 +115,14 @@ func TestBindings(t *testing.T) {
 			endpoint: v1alpha1.Endpoint{
 				Ref: &corev1.ObjectReference{
 					Kind:       "Broker",
-					APIVersion: "eventing.knative.dev/v1beta1",
+					APIVersion: "eventing.knative.dev/v1",
 					Name:       "default",
 				},
 				Properties: asEndpointProperties(map[string]string{
 					"type": "myeventtype",
 				}),
 			},
-			uri: "knative:event/myeventtype?apiVersion=eventing.knative.dev%2Fv1beta1&kind=Broker",
+			uri: "knative:event/myeventtype?apiVersion=eventing.knative.dev%2Fv1&kind=Broker",
 		},
 		{
 			endpointType: v1alpha1.EndpointTypeSource,
@@ -211,7 +222,9 @@ func TestBindings(t *testing.T) {
 				Profile:   profile,
 			}
 
-			binding, err := Translate(bindingContext, tc.endpointType, tc.endpoint)
+			binding, err := Translate(bindingContext, EndpointContext{
+				Type: tc.endpointType,
+			}, tc.endpoint)
 			assert.NoError(t, err)
 			assert.NotNil(t, binding)
 			assert.Equal(t, tc.uri, binding.URI)
